@@ -15,4 +15,4 @@
 import doctest
 
 def test_suite():
-    return doctest.DocFileSuite('unicode.txt')
+    return doctest.DocFileSuite('unicode.rst')
